=======
History
=======

0.3.1 (2018-08-27)
------------------
* Add CLI support to pywhip for CSV files

0.3.0 (2018-08-23)
------------------
* Update to new whip specifications
* Support csv and Darwin Core Archive handling
* Add html and json reporting
* Provide updated sphinx documentation

0.2.1 (2018-04-06)
------------------
* Update towards new cerberus version

0.1.1 (2017-09-12)
------------------

* First release on PyPI.
* Package structure with CI integration
* tox testing on multiple Python versions
